pub struct BlockFeeRatesEntry {
pub avg_height: Height,
pub timestamp: Timestamp,
pub percentiles: FeeRatePercentiles,
}Expand description
A single block fee rates data point with percentiles.
Fields
avg_height: Heighttimestamp: Timestamppercentiles: FeeRatePercentilesTrait Implementations
Sourceimpl Debug for BlockFeeRatesEntry
impl Debug for BlockFeeRatesEntry
Sourceimpl JsonSchema for BlockFeeRatesEntry
impl JsonSchema for BlockFeeRatesEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BlockFeeRatesEntry
impl RefUnwindSafe for BlockFeeRatesEntry
impl Send for BlockFeeRatesEntry
impl Sync for BlockFeeRatesEntry
impl Unpin for BlockFeeRatesEntry
impl UnsafeUnpin for BlockFeeRatesEntry
impl UnwindSafe for BlockFeeRatesEntry