pub struct Dollars(/* private fields */);Expand description
US Dollar amount as floating point
Implementations
Sourceimpl Dollars
impl Dollars
pub const ZERO: Self
pub const NAN: Self
pub const fn mint(dollars: f64) -> Self
pub fn round_nearest_cent(self) -> Self
pub fn round_to(self, digits: i32) -> Self
pub fn is_negative(&self) -> bool
pub fn is_zero(&self) -> bool
pub fn halved(self) -> Self
pub fn to_cents(self) -> Cents
Methods from Deref<Target = f64>
pub const RADIX: u32 = 2
pub const BITS: u32 = 64
pub const MANTISSA_DIGITS: u32 = 53
pub const DIGITS: u32 = 15
pub const EPSILON: f64 = 2.2204460492503131e-16_f64
pub const MIN: f64 = -1.7976931348623157e+308_f64
pub const MIN_POSITIVE: f64 = 2.2250738585072014e-308_f64
pub const MAX: f64 = 1.7976931348623157e+308_f64
pub const MIN_EXP: i32 = -1021
pub const MAX_EXP: i32 = 1024
pub const MIN_10_EXP: i32 = -307
pub const MAX_10_EXP: i32 = 308
pub const NAN: f64
pub const INFINITY: f64
pub const NEG_INFINITY: f64
pub const MAX_EXACT_INTEGER: i64
pub const MIN_EXACT_INTEGER: i64
1.62.0 · Sourcepub fn total_cmp(&self, other: &f64) -> Ordering
pub fn total_cmp(&self, other: &f64) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f64. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f64,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f64::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f64::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f64::NAN` could be positive or negative, which will affect the sort order.
if f64::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f64::NAN, -5.0, 0.1, 10.0, 99.0, f64::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f64::INFINITY, f64::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl AddAssign for Dollars
impl AddAssign for Dollars
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
+= operation. Read moreSourceimpl Bytes for Dollars
impl Bytes for Dollars
Sourcetype Array = <f64 as Bytes>::Array
type Array = <f64 as Bytes>::Array
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl CheckedSub<usize> for Dollars
impl CheckedSub<usize> for Dollars
fn checked_sub(self, rhs: usize) -> Option<Self>
Sourceimpl CheckedSub for Dollars
impl CheckedSub for Dollars
fn checked_sub(self, rhs: Self) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for Dollars
impl<'de> Deserialize<'de> for Dollars
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Formattable for Dollars
impl Formattable for Dollars
Sourceimpl From<CentsCompact> for Dollars
impl From<CentsCompact> for Dollars
Sourcefn from(value: CentsCompact) -> Self
fn from(value: CentsCompact) -> Self
Sourceimpl From<CentsSigned> for Dollars
impl From<CentsSigned> for Dollars
Sourcefn from(value: CentsSigned) -> Self
fn from(value: CentsSigned) -> Self
Sourceimpl From<Dollars> for CentsCompact
impl From<Dollars> for CentsCompact
Sourceimpl From<Dollars> for CentsSigned
impl From<Dollars> for CentsSigned
Sourceimpl JsonSchema for Dollars
impl JsonSchema for Dollars
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
$ref keyword. Read moreSourceimpl Ord for Dollars
impl Ord for Dollars
Sourceimpl PartialOrd for Dollars
impl PartialOrd for Dollars
Sourceimpl Pco for Dollars
impl Pco for Dollars
type NumberType = <f64 as Pco>::NumberType
Sourceimpl SubAssign for Dollars
impl SubAssign for Dollars
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
-= operation. Read moreimpl Copy for Dollars
impl Eq for Dollars
impl TransparentPco<<f64 as Pco>::NumberType> for Dollars