pub struct Epoch(/* private fields */);Trait Implementations
Sourceimpl AddAssign for Epoch
impl AddAssign for Epoch
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl Bytes for Epoch
impl Bytes for Epoch
Sourceconst IS_NATIVE_LAYOUT: bool
const IS_NATIVE_LAYOUT: bool
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl CheckedSub for Epoch
impl CheckedSub for Epoch
fn checked_sub(self, rhs: Self) -> Option<Self>
impl Copy for Epoch
Sourceimpl<'de> Deserialize<'de> for Epoch
impl<'de> Deserialize<'de> for Epoch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Epoch
Sourceimpl Formattable for Epoch
impl Formattable for Epoch
Sourceimpl FromCoarserIndex<Epoch> for Height
impl FromCoarserIndex<Epoch> for Height
Sourcefn min_from(coarser: Epoch) -> usize
fn min_from(coarser: Epoch) -> usize
Returns the minimum fine-grained index represented by the coarse index.
Sourcefn max_from_(coarser: Epoch) -> usize
fn max_from_(coarser: Epoch) -> usize
Returns the maximum fine-grained index represented by the coarse index.
Note: May exceed actual data length - use
max_from for bounded results.Sourcefn max_from(coarser: T, len: usize) -> usize
fn max_from(coarser: T, len: usize) -> usize
Returns the maximum fine-grained index, bounded by the data length.
Returns 0 if len is 0 (empty data).
Sourcefn inclusive_range_from(coarser: T, len: usize) -> RangeInclusive<usize> ⓘwhere
T: Clone,
fn inclusive_range_from(coarser: T, len: usize) -> RangeInclusive<usize> ⓘwhere
T: Clone,
Returns the inclusive range of fine-grained indices for the coarse index.
Returns an empty range (1..=0) if len is 0.
Sourceimpl JsonSchema for Epoch
impl JsonSchema for Epoch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Epoch
impl Ord for Epoch
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Epoch
impl PartialOrd for Epoch
Sourceimpl Pco for Epoch
impl Pco for Epoch
const IS_TRANSPARENT: bool
type NumberType = <u16 as Pco>::NumberType
fn to_number(self) -> Self::NumberType
fn from_number(value: Self::NumberType) -> Result<Self>
Sourceimpl PrintableIndex for Epoch
impl PrintableIndex for Epoch
impl StructuralPartialEq for Epoch