#[repr(C)]pub struct OHLCCents {
pub open: Open<Cents>,
pub high: High<Cents>,
pub low: Low<Cents>,
pub close: Close<Cents>,
}Expand description
OHLC (Open, High, Low, Close) data in cents
Fields
open: Open<Cents>high: High<Cents>low: Low<Cents>close: Close<Cents>Trait Implementations
Sourceimpl Bytes for OHLCCents
impl Bytes for OHLCCents
Sourcetype Array = [u8; 32]
type Array = [u8; 32]
The byte array type returned by
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl<'de> Deserialize<'de> for OHLCCents
impl<'de> Deserialize<'de> for OHLCCents
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Formattable for OHLCCents
impl Formattable for OHLCCents
Sourceimpl From<&OHLCCents> for OHLCDollars
impl From<&OHLCCents> for OHLCDollars
Sourceimpl From<OHLCCents> for OHLCDollars
impl From<OHLCCents> for OHLCDollars
Sourceimpl JsonSchema for OHLCCents
impl JsonSchema for OHLCCents
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OHLCCents
impl RefUnwindSafe for OHLCCents
impl Send for OHLCCents
impl Sync for OHLCCents
impl Unpin for OHLCCents
impl UnsafeUnpin for OHLCCents
impl UnwindSafe for OHLCCents