pub struct P2PK65Bytes(/* private fields */);Trait Implementations
Sourceimpl Bytes for P2PK65Bytes
impl Bytes for P2PK65Bytes
Sourcetype Array = <U8x65 as Bytes>::Array
type Array = <U8x65 as Bytes>::Array
The byte array type returned by
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl Clone for P2PK65Bytes
impl Clone for P2PK65Bytes
Sourcefn clone(&self) -> P2PK65Bytes
fn clone(&self) -> P2PK65Bytes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P2PK65Bytes
impl Debug for P2PK65Bytes
Sourceimpl Deref for P2PK65Bytes
impl Deref for P2PK65Bytes
Sourceimpl<'de> Deserialize<'de> for P2PK65Bytes
impl<'de> Deserialize<'de> for P2PK65Bytes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P2PK65Bytes
impl Display for P2PK65Bytes
Sourceimpl Formattable for P2PK65Bytes
impl Formattable for P2PK65Bytes
Sourcefn write_to(&self, buf: &mut Vec<u8>)
fn write_to(&self, buf: &mut Vec<u8>)
Write formatted UTF-8 bytes. Primary method — all others derive from it.
Sourcefn fmt_csv(&self, f: &mut String) -> Result
fn fmt_csv(&self, f: &mut String) -> Result
Write in CSV format. Override for types needing CSV escaping (e.g., quoting commas).
Sourceimpl From<&[u8]> for P2PK65Bytes
impl From<&[u8]> for P2PK65Bytes
Sourceimpl From<P2PK65Bytes> for AddrBytes
impl From<P2PK65Bytes> for AddrBytes
Sourcefn from(value: P2PK65Bytes) -> Self
fn from(value: P2PK65Bytes) -> Self
Converts to this type from the input type.
Sourceimpl From<U8x65> for P2PK65Bytes
impl From<U8x65> for P2PK65Bytes
Sourceimpl Hash for P2PK65Bytes
impl Hash for P2PK65Bytes
Sourceimpl JsonSchema for P2PK65Bytes
impl JsonSchema for P2PK65Bytes
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P2PK65Bytes
impl Ord for P2PK65Bytes
Sourcefn cmp(&self, other: &P2PK65Bytes) -> Ordering
fn cmp(&self, other: &P2PK65Bytes) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P2PK65Bytes
impl PartialEq for P2PK65Bytes
Sourceimpl PartialOrd for P2PK65Bytes
impl PartialOrd for P2PK65Bytes
Sourceimpl Serialize for P2PK65Bytes
impl Serialize for P2PK65Bytes
impl Eq for P2PK65Bytes
impl StructuralPartialEq for P2PK65Bytes