pub struct P2WSHBytes(/* private fields */);Trait Implementations
Sourceimpl Bytes for P2WSHBytes
impl Bytes for P2WSHBytes
Sourcetype Array = <U8x32 as Bytes>::Array
type Array = <U8x32 as Bytes>::Array
The byte array type returned by
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl Clone for P2WSHBytes
impl Clone for P2WSHBytes
Sourcefn clone(&self) -> P2WSHBytes
fn clone(&self) -> P2WSHBytes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P2WSHBytes
impl Debug for P2WSHBytes
Sourceimpl Deref for P2WSHBytes
impl Deref for P2WSHBytes
Sourceimpl<'de> Deserialize<'de> for P2WSHBytes
impl<'de> Deserialize<'de> for P2WSHBytes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P2WSHBytes
impl Display for P2WSHBytes
impl Eq for P2WSHBytes
Sourceimpl Formattable for P2WSHBytes
impl Formattable for P2WSHBytes
Sourcefn write_to(&self, buf: &mut Vec<u8>)
fn write_to(&self, buf: &mut Vec<u8>)
Write formatted UTF-8 bytes. Primary method — all others derive from it.
Sourcefn fmt_csv(&self, f: &mut String) -> Result
fn fmt_csv(&self, f: &mut String) -> Result
Write in CSV format. Override for types needing CSV escaping (e.g., quoting commas).
Sourceimpl From<&[u8]> for P2WSHBytes
impl From<&[u8]> for P2WSHBytes
Sourceimpl From<P2WSHBytes> for AddrBytes
impl From<P2WSHBytes> for AddrBytes
Sourcefn from(value: P2WSHBytes) -> Self
fn from(value: P2WSHBytes) -> Self
Converts to this type from the input type.
Sourceimpl From<U8x32> for P2WSHBytes
impl From<U8x32> for P2WSHBytes
Sourceimpl Hash for P2WSHBytes
impl Hash for P2WSHBytes
Sourceimpl JsonSchema for P2WSHBytes
impl JsonSchema for P2WSHBytes
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P2WSHBytes
impl Ord for P2WSHBytes
Sourcefn cmp(&self, other: &P2WSHBytes) -> Ordering
fn cmp(&self, other: &P2WSHBytes) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P2WSHBytes
impl PartialEq for P2WSHBytes
Sourcefn eq(&self, other: &P2WSHBytes) -> bool
fn eq(&self, other: &P2WSHBytes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P2WSHBytes
impl PartialOrd for P2WSHBytes
Sourceimpl Serialize for P2WSHBytes
impl Serialize for P2WSHBytes
impl StructuralPartialEq for P2WSHBytes