pub struct SeriesSelection {
pub series: SeriesList,
pub index: Index,
pub range: DataRangeFormat,
}Expand description
Selection of series to query
Fields
series: SeriesListRequested series
index: IndexIndex to query
range: DataRangeFormatTrait Implementations
Sourceimpl Debug for SeriesSelection
impl Debug for SeriesSelection
Sourceimpl Deref for SeriesSelection
impl Deref for SeriesSelection
Sourceimpl<'de> Deserialize<'de> for SeriesSelection
impl<'de> Deserialize<'de> for SeriesSelection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<(Index, SeriesList, DataRangeFormat)> for SeriesSelection
impl From<(Index, SeriesList, DataRangeFormat)> for SeriesSelection
Sourcefn from((index, series, range): (Index, SeriesList, DataRangeFormat)) -> Self
fn from((index, series, range): (Index, SeriesList, DataRangeFormat)) -> Self
Converts to this type from the input type.
Sourceimpl From<(Index, SeriesName, DataRangeFormat)> for SeriesSelection
impl From<(Index, SeriesName, DataRangeFormat)> for SeriesSelection
Sourcefn from((index, series, range): (Index, SeriesName, DataRangeFormat)) -> Self
fn from((index, series, range): (Index, SeriesName, DataRangeFormat)) -> Self
Converts to this type from the input type.
Sourceimpl From<SeriesSelectionLegacy> for SeriesSelection
impl From<SeriesSelectionLegacy> for SeriesSelection
Sourcefn from(value: SeriesSelectionLegacy) -> Self
fn from(value: SeriesSelectionLegacy) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for SeriesSelection
impl JsonSchema for SeriesSelection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SeriesSelection
impl RefUnwindSafe for SeriesSelection
impl Send for SeriesSelection
impl Sync for SeriesSelection
impl Unpin for SeriesSelection
impl UnsafeUnpin for SeriesSelection
impl UnwindSafe for SeriesSelection